"""Manager of development zope instances

'instancemanager' is the main executable, it just calls this file to
do the work.
"""

import actions
import config
import configuration
import utils
import logging
import sys
import os
import os.path

log = logging.getLogger('main')

def parseArguments():
    """Parse the arguments, exit on error.
    """

    args = sys.argv[1:]
    if len(args) != 2:
        log.warn("Incorrect number of arguments.")
        usage()
        sys.exit(1)
    project = args[0]
    action = args[1]
    log.debug("Arguments have been read: project=%s, action=%s.",
              project, action)
    return (project, action)

def usage():
    """Print the usage message.
    """

    print "Usage: instancemanager <project> <action>"
    print 'project: the name of the project, available projects are:'
    userDir = os.path.expanduser('~')
    configDir = os.path.join(userDir, config.CONFIGDIR)
    projects = [p.replace('.py', '') for p in os.listdir(configDir)
                if p.endswith('.py')
                and p not in ['__init__.py', 'userdefaults.py']]
    for project in projects:
        print '    %s' % project
    print "action: the action to take, possible actions include:"
    for actionId in actions.ACTIONS:
        action = actions.ACTIONS[actionId]
        print "    %s -- %s" % (actionId, 
                                action.name)

def main():
    utils.initLog('instancemanager.log')
    utils.addConsoleLogging()
    project, actionId = parseArguments()
    projectConfig = configuration.Configuration(project)
    if not actions.ACTIONS.has_key(actionId):
        log.critical("Non-existing action: '%s'.", actionId)
        sys.exit(1)
    actionFactory = actions.ACTIONS[actionId]
    action = actionFactory(configuration=projectConfig)
    action.run()
